#!/bin/sh

# luna firmware upgrade  script
# $1 image destination (0 or 1) 
# Kernel and root file system images are assumed to be located at the same directory named uImage and rootfs respectively
# ToDo: use arugements to refer to kernel/rootfs location.

k_img="uImage"
r_img="rootfs"
img_ver="fwu_ver"
md5_cmp="md5.txt"
md5_cmd="/bin/md5sum"
#md5 run-time result
md5_tmp="md5_tmp" 
md5_rt_result="md5_rt_result.txt"

# Added by Samson
# check if v2801hw
if 
# Modified by Jack.Tam on 2017-05-04. For BUG#0002812.
#        cat /proc/mtd | grep linux
        cat /proc/mtd | grep k1
then    
#        kname="linux"
#        rname="rootfs"
        kname="k"$1""
        rname="r"$1""
elif      
#it's v2801rw check if 16M flash
#        cat /proc/mtd | grep k"$1"
        cat /proc/mtd | grep linux
then            
#        kname="k"$1""
#        rname="r"$1""
        kname="linux"
        rname="rootfs"
# Added by Jack.Tam on 2017-06-06. For BUG#0002847.
        nv setenv sw_commit "0"
# End of BUG#0002847.
# End of BUG#0002812.
else
#it's 8M flash
        kname="k0"
        rname="r0"
#set commit image back to 0, 20161018
	nv setenv sw_commit "0"
fi
echo "==>$kname  ==>$rname"

# Stop this script upon any error
set -e

echo "Updating image $1 with file $2"

# Find out kernel/rootfs mtd partition according to image destination
# Modified by Samson for bug#000269 only one partion for each image 20160318.
#k_mtd="/dev/"`cat /proc/mtd | grep k"$1" | sed 's/:.*$//g'`
#r_mtd="/dev/"`cat /proc/mtd | grep r"$1" | sed 's/:.*$//g'`
k_mtd="/dev/"`cat /proc/mtd | grep "$kname" | sed 's/:.*$//g'`
r_mtd="/dev/"`cat /proc/mtd | grep "$rname" | sed 's/:.*$//g'`

#Ended by Samson.
echo "kernel image is located at $k_mtd"
echo "rootfs image is located at $r_mtd"

#Bohannon add for bug#00003181
flash set CWMP_CT_MWBAND_MODE 0
flash set HW_CWMP_PRODUCTCLASS DG-GR1321
flash set SUSER_NAME admin
flash set SUSER_PASSWORD admin
flash set TELNET_USER admin
flash set TELNET_PASSWD admin
flash set NTP_TIMEZONE_DB_INDEX 48
flash set WLAN_MBSSIB_TBL.0.ssid DIGISOL
flash set WLAN_MBSSIB_TBL.1.ssid DIGISOL
flash set WLAN_MBSSIB_TBL.2.ssid DIGISOL
flash set WLAN_MBSSIB_TBL.3.ssid DIGISOL
flash set VoiceService.0.TONE_OF_COUNTRY 1

# Extract kernel image
tar -xf $2 $k_img -O | md5sum | sed 's/-/'$k_img'/g' > $md5_rt_result
# Check integrity
grep $k_img $md5_cmp > $md5_tmp
diff $md5_rt_result $md5_tmp

if [ $? != 0 ]; then
    echo "$k_img""md5_sum inconsistent, aborted image updating !"
    exit 1
fi

# Extract rootfs image
tar -xf $2 $r_img -O | md5sum | sed 's/-/'$r_img'/g' > $md5_rt_result
# Check integrity
grep $r_img $md5_cmp > $md5_tmp
diff $md5_rt_result $md5_tmp

if [ $? != 0 ]; then
    # rm $r_img
    echo "$r_img""md5_sum inconsistent, aborted image updating !"
    exit 1
fi

echo "Integrity of $k_img & $r_img is okay, start updating"

# Erase kernel partition 
flash_eraseall $k_mtd
# Write kernel partition
echo "Writing $k_img to $k_mtd"
tar -xf $2 $k_img -O > $k_mtd

# Erase rootfs partition 
flash_eraseall $r_mtd
# Write rootfs partition
echo "Writing $r_img to $r_mtd"
tar -xf $2 $r_img -O > $r_mtd

# Write image version information 
tar -xf $2 $img_ver 
# Modified by Jack.Tam on 2017-06-06. For BUG#0002847.
#nv setenv sw_version"$1" "`cat $img_ver`"
nv setenv sw_version"$1" "V6.0.1P2T8"
# End of BUG#0002847.

# Clean up temporary files
rm -f $md5_cmp $md5_tmp $md5_rt_result $img_ver $2

# Post processing (for future extension consideration)

echo "Successfully updated image $1!!"

